@@ -1,4 +1,4 @@
-use bevy::{prelude::*, utils::HashMap};
+use bevy::prelude::*;
 use bevy_egui::egui;
 
 use crate::{Context, Inspectable};
@@ -24,13 +24,12 @@ impl Default for QuatAttributes {
     }
 }
 
-enum QuatEditState {
-    Euler(Vec3),
-    YawPitchRoll((f32, f32, f32)),
-    AxisAngle((Vec3, f32)),
-}
-#[derive(Default)]
-struct QuatEditStates(HashMap<egui::Id, QuatEditState>);
+#[derive(Clone)]
+struct Euler(Vec3);
+#[derive(Clone)]
+struct YawPitchRoll((f32, f32, f32));
+#[derive(Clone)]
+struct AxisAngle((Vec3, f32));
 
 impl Inspectable for Quat {
     type Attributes = QuatAttributes;
@@ -48,70 +47,55 @@ impl Inspectable for Quat {
                 changed
             }
             QuatDisplay::Euler => {
-                let world = expect_world!(ui, context, "Quat");
-                let mut states = world.get_resource_or_insert_with(QuatEditStates::default);
-                let state = states
-                    .0
-                    .entry(context.id())
-                    .or_insert_with(|| QuatEditState::Euler(to_euler_angles(*self)));
-
-                let euler_angles = match state {
-                    QuatEditState::Euler(euler) => euler,
-                    _ => unreachable!("invalid quat edit state"),
-                };
+                let mut euler_angles = ui
+                    .memory()
+                    .id_data_temp
+                    .get_mut_or_insert_with(context.id(), || Euler(to_euler_angles(*self)))
+                    .0;
 
                 let changed = euler_angles.ui(ui, Default::default(), context);
                 if changed {
-                    *self = from_euler_angles(*euler_angles);
+                    *self = from_euler_angles(euler_angles);
+                    *ui.memory().id_data_temp.get_mut(&context.id()).unwrap() = Euler(euler_angles);
                 }
                 changed
             }
             QuatDisplay::YawPitchRoll => {
-                let world = expect_world!(ui, context, "Quat");
-                let mut states = world.get_resource_or_insert_with(QuatEditStates::default);
-                let state = states
-                    .0
-                    .entry(context.id())
-                    .or_insert_with(|| QuatEditState::YawPitchRoll(yaw_pitch_roll(*self)));
-
-                let (yaw, pitch, roll) = match state {
-                    QuatEditState::YawPitchRoll((y, p, r)) => (y, p, r),
-                    _ => unreachable!("invalid quat edit state"),
-                };
+                let (mut yaw, mut pitch, mut roll) = ui
+                    .memory()
+                    .id_data_temp
+                    .get_mut_or_insert_with(context.id(), || YawPitchRoll(yaw_pitch_roll(*self)))
+                    .0;
 
                 let mut changed = false;
                 ui.vertical(|ui| {
                     egui::Grid::new("ypr grid").show(ui, |ui| {
                         ui.label("Yaw");
-                        changed |= ui.drag_angle(yaw).changed();
+                        changed |= ui.drag_angle(&mut yaw).changed();
                         ui.end_row();
                         ui.label("Pitch").changed();
-                        changed |= ui.drag_angle(pitch).changed();
+                        changed |= ui.drag_angle(&mut pitch).changed();
                         ui.end_row();
                         ui.label("Roll");
-                        changed |= ui.drag_angle(roll).changed();
+                        changed |= ui.drag_angle(&mut roll).changed();
                         ui.end_row();
                     });
                 });
 
                 if changed {
-                    *self = Quat::from_rotation_ypr(*yaw, *pitch, *roll);
+                    *self = Quat::from_rotation_ypr(yaw, pitch, roll);
+                    *ui.memory().id_data_temp.get_mut(&context.id()).unwrap() =
+                        YawPitchRoll((yaw, pitch, roll));
                 }
 
                 changed
             }
             QuatDisplay::AxisAngle => {
-                let world = expect_world!(ui, context, "Quat");
-                let mut states = world.get_resource_or_insert_with(QuatEditStates::default);
-                let state = states
-                    .0
-                    .entry(context.id())
-                    .or_insert_with(|| QuatEditState::AxisAngle(self.to_axis_angle()));
-
-                let (axis, angle) = match state {
-                    QuatEditState::AxisAngle((axis, angle)) => (axis, angle),
-                    _ => unreachable!("invalid quat edit state"),
-                };
+                let (mut axis, mut angle) = ui
+                    .memory()
+                    .id_data_temp
+                    .get_mut_or_insert_with(context.id(), || AxisAngle(self.to_axis_angle()))
+                    .0;
 
                 let mut changed = false;
                 ui.vertical(|ui| {
@@ -120,12 +104,14 @@ impl Inspectable for Quat {
                         changed |= axis.ui(ui, Default::default(), context);
                         ui.end_row();
                         ui.label("Angle");
-                        changed |= ui.drag_angle(angle).changed();
+                        changed |= ui.drag_angle(&mut angle).changed();
                         ui.end_row();
                     });
                 });
                 if changed {
-                    *self = Quat::from_axis_angle(axis.normalize(), *angle);
+                    *self = Quat::from_axis_angle(axis.normalize(), angle);
+                    *ui.memory().id_data_temp.get_mut(&context.id()).unwrap() =
+                        AxisAngle((axis, angle));
                 }
                 changed
             }
