@@ -17,7 +17,7 @@ impl Inspectable for World {
         options: Self::Attributes,
         context: &crate::Context,
     ) -> bool {
-        let mut world_ui_ctx = WorldUIContext::new(context.ui_ctx, self);
+        let mut world_ui_ctx = WorldUIContext::new(self, context.ui_ctx);
         world_ui_ctx.world_ui::<()>(ui, &options)
     }
 }
@@ -48,7 +48,7 @@ impl Inspectable for Entity {
             world.get_resource_or_insert_with(WorldInspectorParams::default);
         let params = std::mem::replace(&mut *world_inspector_params, WorldInspectorParams::empty());
 
-        let world_ui_ctx = WorldUIContext::new(context.ui_ctx, world);
+        let world_ui_ctx = WorldUIContext::new(world, context.ui_ctx);
         let changed = ui
             .vertical(|ui| world_ui_ctx.entity_ui_inner(ui, *self, &params, context.id(), &options))
             .inner;
@@ -204,8 +204,12 @@ where
             let has_more = iter.next().is_some();
 
             match (value, has_more) {
-                (None, _) => todo!(),
-                (Some(_), true) => todo!(),
+                (None, _) => {
+                    ui.label("No entity matches the query.");
+                }
+                (Some(_), true) => {
+                    ui.label("More than one entity matches the query.");
+                }
                 (Some(mut value), false) => {
                     let name = pretty_type_name::pretty_type_name::<Q>();
                     CollapsingHeader::new(name)
