@@ -97,24 +97,35 @@ impl Default for WorldInspectorParams {
         .collect();
         params.read_only_components = [TypeId::of::<GlobalTransform>()].iter().copied().collect();
 
+        #[cfg(feature = "rapier")]
+        {
+            params
+                .ignore_components
+                .insert(TypeId::of::<bevy_rapier3d::prelude::RigidBodyIds>());
+            params
+                .ignore_components
+                .insert(TypeId::of::<bevy_rapier3d::prelude::ColliderBroadPhaseData>());
+        }
+        #[cfg(feature = "rapier2d")]
+        {
+            params
+                .ignore_components
+                .insert(TypeId::of::<bevy_rapier2d::prelude::RigidBodyIds>());
+            params
+                .ignore_components
+                .insert(TypeId::of::<bevy_rapier2d::prelude::ColliderBroadPhaseData>());
+        }
+
         params
     }
 }
 
-struct WorldUIContext<'a> {
+/// Context for providing the [`WorldInspectorPlugin`](crate::WorldInspectorPlugin)'s ui
+pub struct WorldUIContext<'a> {
     world: &'a mut World,
     ui_ctx: Option<&'a egui::CtxRef>,
     delete_entity: Cell<Option<Entity>>,
 }
-impl<'a> WorldUIContext<'a> {
-    fn new(ui_ctx: Option<&'a egui::CtxRef>, world: &'a mut World) -> WorldUIContext<'a> {
-        WorldUIContext {
-            world,
-            ui_ctx,
-            delete_entity: Cell::new(None),
-        }
-    }
-}
 
 impl Drop for WorldUIContext<'_> {
     fn drop(&mut self) {
@@ -125,14 +136,17 @@ impl Drop for WorldUIContext<'_> {
 }
 
 impl<'a> WorldUIContext<'a> {
-    fn entity_name(&self, entity: Entity) -> Cow<'_, str> {
-        match self.world.get_entity(entity) {
-            Some(entity) => guess_entity_name(entity),
-            None => format!("Entity {} (inexistent)", entity.id()).into(),
+    /// Create a new world ui context.
+    pub fn new(world: &'a mut World, ui_ctx: Option<&'a egui::CtxRef>) -> WorldUIContext<'a> {
+        WorldUIContext {
+            world,
+            ui_ctx,
+            delete_entity: Cell::new(None),
         }
     }
 
-    fn world_ui<F>(&mut self, ui: &mut egui::Ui, params: &WorldInspectorParams) -> bool
+    /// Displays the world inspector UI.
+    pub fn world_ui<F>(&mut self, ui: &mut egui::Ui, params: &WorldInspectorParams) -> bool
     where
         F: WorldQuery,
         F::Fetch: FilterFetch,
@@ -146,7 +160,7 @@ impl<'a> WorldUIContext<'a> {
         let mut changed = false;
 
         for entity in root_entities.iter(self.world) {
-            changed |= self.entity_ui(ui, entity, params, dummy_id, &entity_options);
+            changed |= self.entity_ui(ui, entity, params, dummy_id.with(entity), &entity_options);
         }
 
         changed
@@ -214,7 +228,7 @@ impl<'a> WorldUIContext<'a> {
         if let Some(children) = children {
             ui.label("Children");
             for &child in children.iter() {
-                self.entity_ui(ui, child, params, id, entity_options);
+                self.entity_ui(ui, child, params, id.with(child), entity_options);
             }
         } else {
             ui.label("No children");
@@ -294,8 +308,9 @@ impl<'a> WorldUIContext<'a> {
         let type_registry = self.world.get_resource::<TypeRegistryArc>().unwrap();
         let type_registry = &*type_registry.internal.read();
 
+        let id = id.with(component_info.id());
         CollapsingHeader::new(name)
-            .id_source(id.with(component_info.id()))
+            .id_source(id)
             .show(ui, |ui| {
                 if params.is_read_only(type_id) {
                     ui.set_enabled(false);
@@ -303,8 +318,8 @@ impl<'a> WorldUIContext<'a> {
 
                 let world_ptr = self.world as *const _ as *mut _;
                 let context = unsafe {
-                    Context::new_ptr(self.ui_ctx, world_ptr)
-                        .with_id(component_info.id().index() as u64)
+                    let id = id_to_u64(&id);
+                    Context::new_ptr(self.ui_ctx, world_ptr).with_id(id)
                 };
 
                 let result = unsafe {
@@ -330,6 +345,13 @@ impl<'a> WorldUIContext<'a> {
             .body_returned
             .unwrap_or(false)
     }
+
+    fn entity_name(&self, entity: Entity) -> Cow<'_, str> {
+        match self.world.get_entity(entity) {
+            Some(entity) => guess_entity_name(entity),
+            None => format!("Entity {} (inexistent)", entity.id()).into(),
+        }
+    }
 }
 
 /// Safety:
@@ -488,3 +510,12 @@ fn guess_entity_name(entity: EntityRef) -> Cow<'_, str> {
 
     format!("Entity {}", entity.id().id()).into()
 }
+
+fn id_to_u64(id: &egui::Id) -> u64 {
+    use std::collections::hash_map::DefaultHasher;
+    use std::hash::Hash;
+    use std::hash::Hasher;
+    let mut hasher = DefaultHasher::default();
+    id.hash(&mut hasher);
+    hasher.finish()
+}
